Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(380)

Unified Diff: pkg/mbedtls/lib/mbedtls.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/lk/lib/framebuffer.dart ('k') | pkg/mdns/bin/mdns-resolve.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/mbedtls/lib/mbedtls.dart
diff --git a/pkg/mbedtls/lib/mbedtls.dart b/pkg/mbedtls/lib/mbedtls.dart
index ef616d069225a264c440f863781af41a7a26ae37..6cc8ed68982b61b6deed628a6119150e7a9d86dc 100644
--- a/pkg/mbedtls/lib/mbedtls.dart
+++ b/pkg/mbedtls/lib/mbedtls.dart
@@ -1,9 +1,9 @@
-// Copyright (c) 2016, the Fletch project authors. Please see the AUTHORS file
+// Copyright (c) 2016, the Dartino project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-import 'dart:fletch.ffi';
-import 'dart:fletch';
+import 'dart:dartino.ffi';
+import 'dart:dartino';
import 'dart:typed_data';
import 'package:os/os.dart';
import 'package:socket/socket.dart';
@@ -127,9 +127,9 @@ class TLSSocket implements Socket {
final buf =
new ForeignMemory.allocatedFinalized(1024);
final pers =
- new ForeignMemory.fromStringAsUTF8('ssl_client_fletch');
+ new ForeignMemory.fromStringAsUTF8('ssl_client_dartino');
- // The fletch socket we use to do the actual network communication.
+ // The dartino socket we use to do the actual network communication.
Socket _socket;
final String server;
« no previous file with comments | « pkg/lk/lib/framebuffer.dart ('k') | pkg/mdns/bin/mdns-resolve.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698